#
# spec file for package libchipcard
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libchipcard
Version:        5.1.6
Release:        1.12
%define _version 5.1.6
Summary:        Library That Allows Access to Smart Cards (Chipcards)
License:        GPL-2.0-or-later
Group:          Hardware/Other
URL:            https://www.aquamaniac.de/rdm/projects/libchipcard/
Source:         https://www.aquamaniac.de/rdm/attachments/download/382/libchipcard-5.1.6.tar.gz
Source1:        https://www.aquamaniac.de/rdm/attachments/download/381/libchipcard-5.1.6.tar.gz.asc
Source100:      libchipcard-rpmlintrc
Patch0:         libchipcard-buildsrcdoc.patch
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  graphviz
BuildRequires:  graphviz-gd
BuildRequires:  gwenhywfar-devel
BuildRequires:  gwenhywfar-tools
BuildRequires:  pcsc-lite-devel
BuildRequires:  pkg-config
BuildRequires:  zlib-devel

%description
Libchipcard allows access to smart cards. It provides basic access
to memory and processor cards and has special support for German
medical cards, German "Geldkarten," and HBCI (home banking) cards (both
type 0 and type 1). It accesses the readers via CTAPI or PC/SC
interfaces and has successfully been tested with Towitoko, Kobil, and
Reiner-SCT readers.

%package -n libchipcard6
Summary:        Library That Allows Access to Smart Cards (Chipcards)
Group:          System/Libraries
Requires:       %{name} >= %{version}

%description -n libchipcard6
This package contains all necessary include files and libraries needed
to develop applications that require these.

%package devel
Summary:        Header files for libchipcard, a library for accessing smartcards
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       gwenhywfar-devel
Requires:       libchipcard6 = %{version}
Requires:       libusb-devel
Requires:       pcsc-lite-devel
Requires:       sysfsutils

%description devel
This package contains all necessary include files and libraries needed
to develop applications that require these.

%prep
%setup -q -n %{name}-%{_version}
%patch0 -p1
# And update clones of include files to prevent clash:
cp -a /usr/include/PCSC/*.h src/PCSC/

%build
%configure\
	--enable-release\
	--enable-full-doc\
	--disable-static\
        --with-pcsc-libs=%{_libdir}
%make_build
make srcdoc

%install
%make_install
mkdir -p %{buildroot}%{_docdir}/%{name}
cp -a AUTHORS COPYING ChangeLog NEWS README TODO apidoc %{buildroot}%{_docdir}/%{name}
rm %{buildroot}%{_libdir}/*.la

%fdupes %{buildroot}%{_docdir}/%{name}/apidoc

%preun
# Unconditionally stop the service if it exists. Libchipcard 5 uses pcsc now.
[ -x /etc/init.d/chipcardd ] && /etc/init.d/chipcardd stop || true

%post -n libchipcard6 -p /sbin/ldconfig

%postun -n libchipcard6 -p /sbin/ldconfig

%files
%doc %{_docdir}/%{name}
%exclude %{_docdir}/%{name}/apidoc
%{_bindir}/*
%exclude %{_bindir}/*-config
%{_datadir}/chipcard
# Own dirs to fix build.
%dir %{_libdir}/gwenhywfar/
%dir %{_libdir}/gwenhywfar/plugins/
%dir %{_libdir}/gwenhywfar/plugins/*
%{_libdir}/gwenhywfar/plugins/*/ct
%config %{_sysconfdir}/chipcard

%files -n libchipcard6
%{_libdir}/libchipcard.so.6*

%files devel
%doc %{_docdir}/%{name}/apidoc
%{_bindir}/*-config
%{_libdir}/*.so
%{_libdir}/pkgconfig/%{name}*.pc
%{_datadir}/aclocal/*.m4
%{_includedir}/*

%changelog
* Fri Sep 24 2021 Johannes Engel <jcnengel@gmail.com>
- Update to 5.1.6
  + Changed project URL
  + Code cleanup
  + Small bugfixes
* Mon Jun  7 2021 Jan Engelhardt <jengelh@inai.de>
- Drop --with-pic (no effect with --disable-static).
- Modernize rpm macro constructs.
- Make description neutral.
* Thu Sep 24 2020 Torsten Duwe <duwe@suse.com>
- Update to 5.1.5 ("rc2")
  + support for ChipTAN USB
  + many fixes for ZKA cards
* Mon Sep 30 2019 wbauer@tmo.at
- Don't hardcode gwenhywfar-plugins version in the filelist, to fix
  build with newer gwenhywfar
* Tue Jul 31 2018 crrodriguez@opensuse.org
- Remove insserv_prereq, not needed for package to work.
* Fri Jul 21 2017 sbrabec@suse.com
- Set version tag for beta version lower than 5.1.0.
* Tue May 30 2017 nico.kruber@gmail.com
- Update to version 5.1.0beta:
  + support ZKA cards for home banking (by Holger Magnussen)
* Wed Apr  6 2016 nico.kruber@gmail.com
- Update to version 5.0.4:
  + change build system to support newer distributions
- Update to version 5.0.3beta:
  + remove special handling for the cyberJack reader
    (it was unclear whether this was actually needed)
  + now, cyberJack readers get the same commands as any other
    reader (this hopefully fixes some problems with them)
  + if problems with cyberJack continue, please contact the
    Reiner SCT support
* Sun Feb 23 2014 zaitor@opensuse.org
- Own dirs to fix build for 13.2 and newer.
* Sat Jun 11 2011 Nico.Laus.2001@gmx.de
- Update to version 5.0.2
  + now works with the newest pcsclite
  + 'kvkcard read' works again with card readers understanding the
    "RAW" protocol
* Fri Jan  7 2011 sbrabec@suse.cz
- Ported to pcsc-lite-1.6.
* Sun Sep 12 2010 dimstar@opensuse.org
- Update to version 5.0.0
  + First stable release of the 5.x series
  + Do not create an own service anymore. Instead, depend on pc/sc
    service. Old versions did conflict, which caused a lot of
    problems.
  + Require gwenhywfar 4
- Rename base package to libchipcard (avoid the need to rename it
  with the next major release again)
- Drop shlib subpackages libchipcardc2 and libchipcard_ctapi0
- Add new subpackage libchipcard6
- Clean BuildRequires: Remove libusb-devel, opensc-devel, hal,
  hal-devel,  pkg-config, xorg-x11-fonts
- Add zlib-devel BuildRequires.
- As there is no longer an init script, stop it in preun in case
  it still exists from a previous version.
* Tue Jan  5 2010 sbrabec@suse.cz
- Use ">=" in shared library version requirements.
* Sun Jan  3 2010 Nico.Laus.2001@gmx.de
- Updated to 4.2.9:
  + fixes some issues of the chipcard daemons with HAL
  + removed SysFS code
- added a source archive which does not include the sources twice
* Mon Dec 21 2009 Nico.Laus.2001@gmx.de
- made compile with openSUSE 11.1
- added correct source URL
- adapted package to the new structure of the gwenhywfar package
* Fri Aug 14 2009 sbrabec@suse.cz
- Split according to shared library packaging policy.
- Link init script.
- Do not call fillup.
* Tue Aug  4 2009 mkudlvasr@suse.cz
- fix build, some paths have changed
* Tue Jun 30 2009 mkudlvasr@suse.cz
- update to 4.2.8
* Mon May 12 2008 coolo@suse.de
- fix update of 10.1
* Tue Apr 15 2008 schwab@suse.de
- Fix configure script.
* Fri Nov  9 2007 crrodriguez@suse.de
- fix build adding missing prereq insserv_prereq fillup_prereq
- update to version 3.0.4
- added reader description for new Cyberjack readers
- remove static libraries and "la" files
* Fri Aug  3 2007 aj@suse.de
- Add gcc-c++ to build requires.
* Mon Jul 30 2007 sbrabec@suse.cz
- Package branched to libchipcard3.
- Updated to version 3.0.3:
  * Design changes.
  * New API.
  * See NEWS for details.
- Build and install apidoc.
* Wed May 16 2007 olh@suse.de
- Buildrequires libusb -> libusb-devel
* Wed Sep 27 2006 stbinner@suse.de
- Update to version 2.1.9:
  * remove an annoying log message on no-PCMCIA systems
  * work with the latest generic CCID driver
  * fix a bug which prevented autodetecting of PCMCIA devices
  * this version now works with OpenSC 0.11.x as well
* Mon Jul 17 2006 stbinner@suse.de
- Update to version 2.1.7:
  * allows readers without a keyboard to verify the pin of a
    chipcard again.
  * fixes a problem with newer GeldKarte cards
  * now uses LibSysFS primarily to detect /dev/ttyUSB devices
* Tue Jun 20 2006 stbinner@suse.de
- Update to version 2.1.6:
  * no longer requires the kernel sources to provide support for
    PCMCIA autoconfiguration
  * no longer needs a specially compiled version of libccid to
    work with that driver; the normal binary packages suffice.
* Tue May 16 2006 sbrabec@suse.cz
- Fixed BuildRequires.
* Mon May 15 2006 sbrabec@suse.cz
- Obsolete libchipcard-tools.
* Tue May  9 2006 sbrabec@suse.cz
- Updated to version 2.1.4 (libchipcard2).
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 11 2006 stbinner@suse.de
- fix nfb
* Mon Dec 19 2005 dmueller@suse.de
- fix file list
* Mon Aug  1 2005 dmueller@suse.de
- fix m4 quoting warning
* Mon Apr 11 2005 coolo@suse.de
- fix one 64bit problem with gcc4
* Thu Feb 17 2005 ro@suse.de
- fixed file list
* Sat Jan 22 2005 ro@suse.de
- fix build after pcsc-lite update
* Fri Nov 19 2004 coolo@suse.de
- cleaning up desktop files
* Wed Aug  4 2004 coolo@suse.de
- libtoolize so the tools are in sync
* Fri Apr 16 2004 coolo@suse.de
- build without unsermake
* Sat Mar 13 2004 coolo@suse.de
- fixing encoding of the desktop file
* Tue Mar  2 2004 ro@suse.de
- fix build on s390,s390x
* Thu Oct 30 2003 ro@suse.de
- fix build libchipcard-kde (include local m4 macros)
* Wed Sep 10 2003 coolo@suse.de
- add restart|stop calls to the %%p* scripts (#29025)
* Tue Aug 12 2003 ro@suse.de
- fix patch/build for lib64
* Sat Aug  9 2003 adrian@suse.de
- add Categories
- update to version 0.9.1
* Thu Jul 31 2003 meissner@suse.de
- do not leave -L/usr/lib references on lib64 systems, to
  avoid confusion on biarch systems.
* Tue Jul 22 2003 coolo@suse.de
- don't give libtool a chance to leave build root traces
* Thu Jun 12 2003 coolo@suse.de
- running ldconfig
- packaging directories
- adding require on lib package
- putting translations into %%lang
* Fri May 16 2003 coolo@suse.de
- giving Mads reasons
* Thu Apr 10 2003 coolo@suse.de
- updating to 0.8.2 and fixing file list
* Tue Feb 18 2003 coolo@suse.de
- fixing build on lib64
* Tue Feb 18 2003 ro@suse.de
- move all config-files in place
* Mon Feb 17 2003 ro@suse.de
- fixed specfile
* Mon Feb 17 2003 coolo@suse.de
- initial package
